Module objects

Module objects 

Map objects: points, lines, areas, and text.

Structs

AreaObject
An area (polygon) object on the map.
BezierPath
A mixed straight/cubic Bézier path with dash-point metadata on its vertices.
BezierPolygon
A polygon whose exterior and interior rings retain straight and cubic Bézier segments.
BezierString
A BezierString is simply a vector of BezierSegments
LineObject
A line object represented as a polyline on the map.
PatternRotation
A fill pattern rotation and origin used by area objects.
PointObject
A point object placed at a single location on the map.
TextObject
A text object placed on the map.
WrapBox
A rectangular bounding box for wrapped text.

Enums

BezierSegment
A BezierSegment is either a straight Line or a BezierCurve
HorizontalAlign
Horizontal text alignment.
MapObject
A map object that can be a point, line, area, or text.
TextGeometry
The geometry of a text object, which is either a single anchor or a wrap box.
VerticalAlign
Vertical text alignment.

Constants

COORD_FLAG_CLOSE_POINT
A coordinate closes the current path.
COORD_FLAG_CURVE_START
A coordinate starts a cubic Bézier segment.
COORD_FLAG_DASH_POINT
A coordinate is a forced dash point.
COORD_FLAG_GAP_POINT
A coordinate is the endpoint of a line-symbol gap.
COORD_FLAG_HOLE_POINT
A coordinate closes an interior polygon ring.