BezierSegment

Enum BezierSegment 

pub enum BezierSegment<T = f64>
where T: CoordFloat,
{ Bezier(BezierCurve<T>), Line(Line<T>), }
A BezierSegment is either a straight Line or a BezierCurve

Variants



Bezier(BezierCurve<T>)

The segment is a cubic bezier



Line(Line<T>)

The segment is a line

Implementations

Source

impl<T> BezierSegment<T>
where T: CoordFloat,

pub fn is_bezier_curve(&self) -> bool

Is this segment a cubic bezier?

pub fn start(&self) -> Coord<T>

Return the start coordinate of this segment

pub fn end(&self) -> Coord<T>

Return the end coordinate of this segment

pub fn handles(&self) -> Option<(Coord<T>, Coord<T>)>

Return the handles of this segment, or None if this segment is a line

pub fn new( start: Coord<T>, handles: Option<(Coord<T>, Coord<T>)>, end: Coord<T>, ) -> BezierSegment<T>

Construct a Bezier segment given the start, end and optionally two handles

pub fn length_approximation(&self) -> T

Get an approximation of the euclidean length of the bezier segment For the cubic bezier this is taken as the mean of the distance between the end points and the distance from start to end through the handles For the line it is simple the euclidean line length

pub fn to_line_string(&self, error: T) -> Result<LineString<T>, Error>

Get a LineString with at most error deviation from the Bezier segment