WeakSymbol

Enum WeakSymbol 

pub enum WeakSymbol {
    Line(Weak<RefCell<LineSymbol>>),
    Area(Weak<RefCell<AreaSymbol>>),
    Point(Weak<RefCell<PointSymbol>>),
    Text(Weak<RefCell<TextSymbol>>),
    CombinedArea(Weak<RefCell<CombinedAreaSymbol>>),
    CombinedLine(Weak<RefCell<CombinedLineSymbol>>),
}
A non-owning reference to a symbol of any type.

Variants



Line(Weak<RefCell<LineSymbol>>)

A weak reference to a line symbol.



Area(Weak<RefCell<AreaSymbol>>)

A weak reference to an area symbol.



Point(Weak<RefCell<PointSymbol>>)

A weak reference to a point symbol.



Text(Weak<RefCell<TextSymbol>>)

A weak reference to a text symbol.



CombinedArea(Weak<RefCell<CombinedAreaSymbol>>)

A weak reference to a combined area symbol.



CombinedLine(Weak<RefCell<CombinedLineSymbol>>)

A weak reference to a combined line symbol.

Implementations

Source

impl WeakSymbol

pub fn upgrade(&self) -> Option<Symbol>

Attempts to upgrade the WeakSymbol to a Symbol, delaying dropping of the inner value if successful. Returns None if the inner value has since been dropped.