Map objects: points, lines, areas, and text.
Structs
- Area
Object - An area (polygon) object on the map.
- Bezier
Path - A mixed straight/cubic Bézier path with dash-point metadata on its vertices.
- Bezier
Polygon - A polygon whose exterior and interior rings retain straight and cubic Bézier segments.
- Bezier
String - A BezierString is simply a vector of BezierSegments
- Line
Object - A line object represented as a polyline on the map.
- Pattern
Rotation - A fill pattern rotation and origin used by area objects.
- Point
Object - A point object placed at a single location on the map.
- Text
Object - A text object placed on the map.
- WrapBox
- A rectangular bounding box for wrapped text.
Enums
- Bezier
Segment - A BezierSegment is either a straight Line or a BezierCurve
- Horizontal
Align - Horizontal text alignment.
- MapObject
- A map object that can be a point, line, area, or text.
- Text
Geometry - The geometry of a text object, which is either a single anchor or a wrap box.
- Vertical
Align - Vertical text alignment.
Constants
- COORD_
FLAG_ CLOSE_ POINT - A coordinate closes the current path.
- COORD_
FLAG_ CURVE_ START - A coordinate starts a cubic Bézier segment.
- COORD_
FLAG_ DASH_ POINT - A coordinate is a forced dash point.
- COORD_
FLAG_ GAP_ POINT - A coordinate is the endpoint of a line-symbol gap.
- COORD_
FLAG_ HOLE_ POINT - A coordinate closes an interior polygon ring.