pub enum BezierSegment<T = f64>where
T: CoordFloat,{
Bezier(BezierCurve<T>),
Line(Line<T>),
}Expand description
A BezierSegment is either a straight Line or a BezierCurve
Variants
Implementations
Sourceimpl<T> BezierSegment<T>where
T: CoordFloat,
impl<T> BezierSegment<T>where
T: CoordFloat,
Sourcepub fn is_bezier_curve(&self) -> bool
pub fn is_bezier_curve(&self) -> bool
Is this segment a cubic bezier?
Sourcepub fn handles(&self) -> Option<(Coord<T>, Coord<T>)>
pub fn handles(&self) -> Option<(Coord<T>, Coord<T>)>
Return the handles of this segment, or None if this segment is a line
Sourcepub fn new(
start: Coord<T>,
handles: Option<(Coord<T>, Coord<T>)>,
end: Coord<T>,
) -> BezierSegment<T>
pub fn new( start: Coord<T>, handles: Option<(Coord<T>, Coord<T>)>, end: Coord<T>, ) -> BezierSegment<T>
Construct a Bezier segment given the start, end and optionally two handles
Sourcepub fn length_approximation(&self) -> T
pub fn length_approximation(&self) -> T
Get an approximation of the euclidean length of the bezier segment For the cubic bezier this is taken as the mean of the distance between the end points and the distance from start to end through the handles For the line it is simple the euclidean line length
Sourcepub fn to_line_string(&self, error: T) -> Result<LineString<T>, Error>
pub fn to_line_string(&self, error: T) -> Result<LineString<T>, Error>
Get a LineString with at most error deviation from the Bezier segment